==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_item_search_m.js <==
/* Parent class for inheritance */
_me = obj_item_search_m.prototype;
function obj_item_search_m(){};

/**
 * @brief: CONSTRUCTOR
 * @date : 24.5.2007 11:43:07
 **/
_me.__constructor = function(sFolder){

	var me = this;
	function change(){
		if (me.SUBJECT._value() || me.TO._value() || me.FROM._value())
			me.search._disabled(false);
		else
			me.search._disabled(true);
	};

	function numeric(e){
		if ((e.keyCode>95 && e.keyCode<106) || e.keyCode==37 || e.keyCode==39 || e.keyCode==8 || e.keyCode==46 || (e.keyCode == 110 && e.target.value.length>0 && e.target.value.indexOf('.')<0))
			return true;
		else
			return false;
	};

	if (!sFolder) sFolder = (this._parent.list._getFolder())['fid'];        //tohle nak nejde

	sDraft = GWOthers.getItem('DEFAULT_FOLDERS', 'drafts');
    sSent = GWOthers.getItem('DEFAULT_FOLDERS', 'sent');
    
	with(this){
		DATE1._ondateselect = function(v){
			if (me.DATE2._value() && me.DATE2._value()<this._value())
				me.DATE2._value(this._value());
		};

		DATE2._ondateselect = function(v){
			if (this._value()<me.DATE1._value())
				this._value(me.DATE1._value());
		};

		SUBJECT._onclick = change;
		SUBJECT._value(1);
	    TO._onclick = change;
		FROM._onclick = change;

		if (sFolder == sDraft || sFolder == sSent)
		    TO._value(1);
		else
			FROM._value(1);

		SIZE1._onkeydown = numeric;
		SIZE2._onkeydown = numeric;
    }
};

_me._buildSQL = function(){
	var v,SQL = '';

	if ((v = this.search._value()) && typeof v == 'string'){

		v = v.quoteSQL();

		if (this.SUBJECT._value())
			SQL = "(SUBJECT LIKE '%"+v+"%'";
		if (this.TO._value())
			SQL += (SQL?' OR ':'(')+"HEADER_TO LIKE '%"+v+"%'";
		if (this.FROM._value())
			SQL += (SQL?' OR ':'(')+"HEADER_FROM LIKE '%"+v+"%'";
		if (SQL) SQL += ')';
	}
	
	//DATE
	if (this.DATE1._value()){
        var iGWTime = (parseInt(this.DATE1._value()) || 0);
		if (iGWTime>0){
			var oDate = new Date();
				oDate.setGWTime(iGWTime);

			SQL += (SQL?' AND ':'')+"DATE >= "+oDate.getUNIX();
		}
	}
	if (this.DATE2._value()){
        var iGWTime = (parseInt(this.DATE2._value()) || 0);
		if (iGWTime>0){
			var oDate = new Date();
				oDate.setGWTime(iGWTime+1);

			SQL += (SQL?' AND ':'')+"DATE < "+oDate.getUNIX();
		}
	}

	//SIZE
	if (this.SIZE1._value())
		SQL += (SQL?' AND ':'')+"SIZE >= "+((parseInt(this.SIZE1._value()) || 0)*1024);
	if (this.SIZE2._value())
		SQL += (SQL?' AND ':'')+"SIZE <= "+((parseInt(this.SIZE2._value()) || 0)*1024);

	this._value(SQL);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_item_search_m.js <==
/* Parent class for inheritance */
_me = obj_item_search_m.prototype;
function obj_item_search_m(){};

/**
 * @brief: CONSTRUCTOR
 * @date : 24.5.2007 11:43:07
 **/
_me.__constructor = function(sFolder){

	var me = this;
	function change(){
		if (me.SUBJECT._value() || me.TO._value() || me.FROM._value() || me.BODY._value())
			me.search._disabled(false);
		else
			me.search._disabled(true);
	};

	function numeric(e){
		if ((e.keyCode>95 && e.keyCode<106) || e.keyCode==37 || e.keyCode==39 || e.keyCode==8 || e.keyCode==46 || (e.keyCode == 110 && e.target.value.length>0 && e.target.value.indexOf('.')<0))
			return true;
		else{
			if ((e.keyCode>48 && e.keyCode<58))
				e.target.value += (e.keyCode-48);
			else
			if ((e.keyCode == 190 && e.target.value.length>0 && e.target.value.indexOf('.')<0))
				e.target.value += '.';

			return false;
		}
	};


	if (!sFolder) sFolder = (this._parent.list._getFolder())['fid'];        //tohle nak nejde

	sDraft = GWOthers.getItem('DEFAULT_FOLDERS', 'drafts');
    sSent = GWOthers.getItem('DEFAULT_FOLDERS', 'sent');
    
	with(this){
		DATE1._ondateselect = function(v){
			if (me.DATE2._value() && me.DATE2._value()<this._value())
				me.DATE2._value(this._value());
		};

		DATE2._ondateselect = function(v){
			if (this._value()<me.DATE1._value())
				this._value(me.DATE1._value());
		};

		SUBJECT._onclick = change;
		SUBJECT._value(1);
	    TO._onclick = change;
		FROM._onclick = change;
		BODY._onclick = change;

		if (sFolder == sDraft || sFolder == sSent)
		    TO._value(1);
		else
			FROM._value(1);

		SIZE1._onkeydown = numeric;
		SIZE2._onkeydown = numeric;
    }
};

_me._buildSQL = function(){
	var v,SQL = '';

    this.__string = '';
	if ((v = this.search._value()) && typeof v == 'string'){

		v = v.quoteSQL();

		if (this.BODY._value())
		    this.__string = v;

		if (this.SUBJECT._value())
			SQL = "(SUBJECT LIKE '%"+v+"%'";
		if (this.TO._value())
			SQL += (SQL?' OR ':'(')+"HEADER_TO LIKE '%"+v+"%'";
		if (this.FROM._value())
			SQL += (SQL?' OR ':'(')+"HEADER_FROM LIKE '%"+v+"%'";
		if (SQL) SQL += ')';
	}
	
	//DATE
	if (this.DATE1._value()){
        var iGWTime = (parseInt(this.DATE1._value()) || 0);
		if (iGWTime>0){
			var oDate = new Date();
				oDate.setGWTime(iGWTime);

			SQL += (SQL?' AND ':'')+"DATE >= "+oDate.getUNIX();
		}
	}
	if (this.DATE2._value()){
        var iGWTime = (parseInt(this.DATE2._value()) || 0);
		if (iGWTime>0){
			var oDate = new Date();
				oDate.setGWTime(iGWTime+1);

			SQL += (SQL?' AND ':'')+"DATE < "+oDate.getUNIX();
		}
	}

	//SIZE
	if (this.SIZE1._value())
		SQL += (SQL?' AND ':'')+"SIZE >= "+((parseInt(this.SIZE1._value()) || 0)*1024);
	if (this.SIZE2._value())
		SQL += (SQL?' AND ':'')+"SIZE <= "+((parseInt(this.SIZE2._value()) || 0)*1024);

	this._value(SQL);
};
